@@ -39,6 +39,8 @@ public:
 	int  validRec();
 	void checkBand();
 	void checkDateTimes();
+	void setDateTime(bool dtOn);
+	void setFrequency(long long freq);
 // operator overloads
 	const cQsoRec &operator=(const cQsoRec &);
 	bool operator==(const cQsoRec &) const;
@@ -64,7 +66,7 @@ private:
 	int dirty;
 	
 	static const int jdays[][13];
-	bool isleapyear( int y );
+	bool isleapyear( int y ) const;
 	int dayofyear (int year, int mon, int mday);
 	unsigned int epoch_minutes (const char *szdate, const char *sztime);	
 public:
@@ -75,14 +77,14 @@ public:
 	void deleteRecs();
 	void clearDatabase();
 	void isdirty(int n) {dirty = n;}
-	int  isdirty() {return dirty;}
+	int  isdirty() const {return dirty;}
 	void qsoNewRec (cQsoRec *);
 	cQsoRec *newrec();
 	void qsoDelRec (int);
 	void qsoUpdRec (int, cQsoRec *);
 	int qsoFindRec (cQsoRec *);
 	cQsoRec *getRec (int n) {return &qsorec[n];};
-	int nbrRecs () {return nbrrecs;};
+	int nbrRecs () const {return nbrrecs;};
 	bool qsoIsValidFile(const char *);
 	int qsoReadFile (const char *);
 	int qsoWriteFile (const char *);
