@@ -79,9 +79,12 @@ void Export_CSV()
 
 	cQsoRec *rec;
 
-	string filters = "CSV\t*." "csv";
-	const char* p = FSEL::saveas(_("Export to CSV file"), filters.c_str(),
-					 "export." "csv");
+	string title = _("Export to CSV file");
+	string filters = "CSV\t*.csv";
+#ifdef __APPLE__
+	filters.append("\n");
+#endif
+	const char* p = FSEL::saveas( title.c_str(), filters.c_str(), "export.csv");
 	if (!p)
 		return;
 
@@ -92,7 +95,9 @@ void Export_CSV()
 			qsodb.qsoUpdRec (i, rec);
 		}
 	}
-	txtFile.writeCSVFile(p, &qsodb);
+	string sp = p;
+	if (sp.find(".csv") == string::npos) sp.append(".csv");
+	txtFile.writeCSVFile(sp.c_str(), &qsodb);
 }
 
 void Export_TXT()
@@ -100,10 +105,12 @@ void Export_TXT()
 	if (chkExportBrowser->nchecked() == 0) return;
 
 	cQsoRec *rec;
-
-	string filters = "TEXT\t*." "txt";
-	const char* p = FSEL::saveas(_("Export to fixed field text file"), filters.c_str(),
-					 "export." "txt");
+	string title = _("Export to fixed field text file");
+	string filters = "TEXT\t*.txt";
+#ifdef __APPLE__
+	filters.append("\n");
+#endif
+	const char* p = FSEL::saveas( title.c_str(), filters.c_str(), "export.txt");
 	if (!p)
 		return;
 
@@ -114,6 +121,8 @@ void Export_TXT()
 			qsodb.qsoUpdRec (i, rec);
 		}
 	}
+	string sp = p;
+	if (sp.find(".txt") == string::npos) sp.append(".txt");
 	txtFile.writeTXTFile(p, &qsodb);
 }
 
@@ -123,9 +132,16 @@ void Export_ADIF()
 
 	cQsoRec *rec;
 
-	string filters = "ADIF\t*." ADIF_SUFFIX;
-	const char* p = FSEL::saveas(_("Export to ADIF file"), filters.c_str(),
-					 "export." ADIF_SUFFIX);
+	string title = _("Export to ADIF file");
+	string filters;
+	string defname;
+	filters.assign("ADIF\t*.").append(ADIF_SUFFIX);
+#ifdef __APPLE__
+	filters.append("\n");
+#endif
+	defname.assign("export.").append(ADIF_SUFFIX);
+	const char* p = FSEL::saveas( title.c_str(), filters.c_str(), defname.c_str());
+
 	if (!p)
 		return;
 
@@ -136,7 +152,9 @@ void Export_ADIF()
 			qsodb.qsoUpdRec (i, rec);
 		}
 	}
-	adifFile.writeFile (p, &qsodb);
+	string sp = p;
+	if (sp.find("."ADIF_SUFFIX) == string::npos) sp.append("."ADIF_SUFFIX);
+	adifFile.writeFile (sp.c_str(), &qsodb);
 }
 
 static savetype export_to = ADIF;
@@ -177,7 +195,7 @@ void cb_mnuNewLogbook(Fl_Menu_* m, void* d){
 	saveLogbook();
 
 	logbook_filename = LogsDir;
-	logbook_filename.append("newlog." ADIF_SUFFIX);
+	logbook_filename.append("newlog.").append(ADIF_SUFFIX);
 	progdefaults.logbookfilename = logbook_filename;
 	dlgLogbook->label(fl_filename_name(logbook_filename.c_str()));
 	progdefaults.changed = true;
@@ -200,8 +218,14 @@ void adif_read_OK()
 
 void cb_mnuOpenLogbook(Fl_Menu_* m, void* d)
 {
-	const char* p = FSEL::select(_("Open logbook file"), "ADIF\t*." ADIF_SUFFIX,
-				     logbook_filename.c_str());
+	string title = _("Open logbook file");
+	string filters;
+	filters.assign("ADIF\t*.").append(ADIF_SUFFIX);
+#ifdef __APPLE__
+	filters.append("\n");
+#endif
+
+	const char* p = FSEL::select( title.c_str(), filters.c_str(), logbook_filename.c_str());
 	if (p) {
 		saveLogbook();
 		qsodb.deleteRecs();
@@ -217,10 +241,17 @@ void cb_mnuOpenLogbook(Fl_Menu_* m, void* d)
 }
 
 void cb_mnuSaveLogbook(Fl_Menu_*m, void* d) {
-	const char* p = FSEL::saveas(_("Save logbook file"), "ADIF\t*." ADIF_SUFFIX,
-				     logbook_filename.c_str());
+	string title = _("Save logbook file");
+	string filter;
+	filter.assign("ADIF\t*.").append(ADIF_SUFFIX);
+#ifdef __APPLE__
+	filter.append("\n");
+#endif
+	const char* p = FSEL::saveas( title.c_str(), filter.c_str(), logbook_filename.c_str());
 	if (p) {
 		logbook_filename = p;
+		if (logbook_filename.find("."ADIF_SUFFIX) == string::npos)
+			logbook_filename.append("."ADIF_SUFFIX);
 		dlgLogbook->label(fl_filename_name(logbook_filename.c_str()));
 
 		cQsoDb::reverse = false;
@@ -1302,11 +1333,14 @@ void WriteCabrillo()
 
 	cQsoRec *rec;
 
+	string title = _("Create cabrillo report");
 	string filters = "TEXT\t*.txt";
+#ifdef __APPLE__
+	filters.append("\n");
+#endif
 	string strContest = "";
 
-	const char* p = FSEL::saveas(_("Create cabrillo report"), filters.c_str(),
-					 "contest.txt");
+	const char* p = FSEL::saveas( title.c_str(), filters.c_str(), "contest.txt");
 	if (!p)
 		return;
 
@@ -1318,6 +1352,8 @@ void WriteCabrillo()
 		}
 	}
 
+	string sp = p;
+	if (sp.find(".txt") == string::npos) sp.append(".txt");
     FILE *cabFile = fopen (p, "w");
     if (!cabFile)
         return;
