@@ -1474,6 +1474,15 @@ static void pWX(std::string &s, size_t &i, size_t endbracket)
 	s.replace(i, 4, wx);
 }
 
+// <WX:metar>
+static void pWX2(std::string &s, size_t &i, size_t endbracket)
+{
+	string wx;
+	getwx(wx, s.substr(i+4, endbracket - i - 4).c_str());
+	s.replace(i, endbracket - i + 1, wx);
+}
+
+
 void set_macro_env(void)
 {
 	enum {
@@ -1971,6 +1980,7 @@ static const MTAGS mtags[] = {
 {"<TALK:",		pTALK},
 #endif
 {"<WX>",		pWX},
+{"<WX:",		pWX2},
 {"<!WPM:",		pQueWPM},
 {"<!RISE:",		pQueRISETIME},
 {"<!PRE:",		pQuePRE},
@@ -2049,15 +2059,18 @@ void MACROTEXT::loadDefault()
 {
 	int erc;
 	std::string Filename = MacrosDir;
+	Filename.append("macros.mdf");
+LOG_INFO("macro file name: %s", progStatus.LastMacroFile.c_str());
 	if (progdefaults.UseLastMacro == true) {
-		if (progStatus.LastMacroFile.find("/") == string::npos)
-			Filename.append(progStatus.LastMacroFile);
-		else
+		if (progStatus.LastMacroFile.find("/") != string::npos ||
+			progStatus.LastMacroFile.find("\\") != string::npos)
 			Filename.assign(progStatus.LastMacroFile);
-	} else {
-		Filename.append("macros.mdf");
-		progStatus.LastMacroFile = Filename;
+		else
+			Filename.assign(MacrosDir).append(progStatus.LastMacroFile);
 	}
+LOG_INFO("loading: %s", Filename.c_str());
+	progStatus.LastMacroFile = Filename;
+
 	if ((erc = loadMacros(Filename)) != 0)
 #ifndef __WOE32__
 		LOG_ERROR("Error #%d loading %s\n", erc, Filename.c_str());
