@@ -55,8 +55,8 @@ modem *mfsk22_modem = 0;
 modem *mfsk31_modem = 0;
 modem *mfsk64_modem = 0;
 
-modem *wefax576 = 0;
-modem *wefax288 = 0;
+modem *wefax576_modem = 0;
+modem *wefax288_modem = 0;
 
 modem *mt63_500_modem = 0;
 modem *mt63_1000_modem = 0;
@@ -119,11 +119,6 @@ modem *wwv_modem = 0;
 modem *anal_modem = 0;
 modem *ssb_modem = 0;
 
-trx_mode modem::get_mode()
-{
-	return mode;
-}
-
 modem::modem()
 {
 	scptr = 0;
@@ -177,12 +172,7 @@ void modem::set_freqlock(bool on)
 }
 
 
-bool modem::freqlocked()
-{
-	return freqlock;
-}
-
-double modem::get_txfreq(void)
+double modem::get_txfreq(void) const
 {
 	if (unlikely(!(cap & CAP_TX)))
 		return 0;
@@ -191,23 +181,13 @@ double modem::get_txfreq(void)
 	return tx_frequency;
 }
 
-double modem::get_txfreq_woffset(void)
+double modem::get_txfreq_woffset(void) const
 {
 	if (mailserver && progdefaults.PSKmailSweetSpot)
 		return (progdefaults.PSKsweetspot - progdefaults.TxOffset);
 	return (tx_frequency - progdefaults.TxOffset);
 }
 
-int modem::get_freq()
-{
-	return (int)(frequency + 0.5);
-}
-
-double modem::get_bandwidth(void)
-{
-	return bandwidth;
-}
-
 void modem::set_bandwidth(double bw)
 {
 	bandwidth = bw;
@@ -230,12 +210,6 @@ void modem::display_metric(double m)
 	::global_display_metric(m);
 }
 
-double modem::get_metric(void)
-{
-	return metric;
-}
-
-
 bool modem::get_cwTrack()
 {
 	return cwTrack;
@@ -271,11 +245,6 @@ void modem::set_cwXmtWPM(double wpm)
 	cwXmtWPM = wpm;
 }
 
-int modem::get_samplerate(void)
-{
-	return samplerate;
-}
-
 void modem::set_samplerate(int smprate)
 {
 	samplerate = smprate;
